(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     65229,       1584]
NotebookOptionsPosition[     61421,       1485]
NotebookOutlinePosition[     61761,       1500]
CellTagsIndexPosition[     61718,       1497]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["UDDER",
  FontSlant->"Italic"],
 ": reducing unbounded verification of DDEs to its bounded counterpart "
}], "Title",
 CellChangeTimes->{{3.765709093391864*^9, 3.765709097247883*^9}, {
  3.7657523592930326`*^9, 3.765752474909906*^9}, {3.765752605652502*^9, 
  3.765752649492135*^9}, {3.766641048129986*^9, 3.766641049754401*^9}, {
  3.766641093562249*^9, 3.766641122322617*^9}, {3.766641156802545*^9, 
  3.7666411622577353`*^9}, {3.766641336218388*^9, 3.766641341297014*^9}}],

Cell[TextData[{
 "The prototypical implementation is dedicated to reducing the verification \
problem of exponentially stable DDEs over an unbounded temporal horizon to \
that over a bounded one. It takes as inputs a verification problem of a \
(linearized) DDE associated with \[Alpha] satisfying \[Alpha]* < \[Alpha] < \
0, where \[Alpha]* is the rightmost eigenvalue obtained through DDE-BIFTOOL, \
and generates a temporal bound ",
 StyleBox["T",
  FontSlant->"Italic"],
 "* such that for any ",
 StyleBox["T",
  FontSlant->"Italic"],
 " > ",
 StyleBox["T",
  FontSlant->"Italic"],
 "*, the system of DDE is safe over [-",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "max"], TraditionalForm]]],
 ", ",
 StyleBox["T",
  FontSlant->"Italic"],
 "] iff it is safe over [-",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "max"], TraditionalForm]]],
 ", \[Infinity]), where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "max"], TraditionalForm]]],
 " > 0 is the maximum constant delay. For linear dynamics, such an \
equivalence of safety applies to any initial set of functions drawn from a \
compact subspace in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalR]", "n"], TraditionalForm]]],
 "; while for nonlinear dynamics, the implementation further produces (a \
subset of) the basin of attraction around the zero equilibrium, in the form \
of ||\[ScriptCapitalB]|| < \[Delta], and therefore a certificate (by bounded \
verification in finitely many steps) that guarantees the reachable set being \
contained in this basin suffices to claim safety/unsafety of the system over \
an infinite time horizon.\n\nCurrent version: v1.0\nValidated on platform: ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 10, 64 bit-Ubuntu-Desktop-16.04\nLatest modification: on May 12, 2019, by \
Mingshuai Chen, SKLCS-ISCAS\n\nCorresponding e-mail: chenms@ios.ac.cn\nList \
of contributors: Mingshuai Chen and Shenghua Feng\n\nComments and bug-reports \
are higly appreciated.\n\[Copyright] 2019 ",
 StyleBox["UDDER",
  FontSlant->"Italic"],
 ", State Key Lab. of Computer Science, ISCAS. All rights reserved."
}], "Text",
 CellChangeTimes->{{3.765709032701655*^9, 3.765709032706498*^9}, {
   3.765709067706286*^9, 3.76570911669053*^9}, 3.765751481701613*^9, {
   3.7657526597253637`*^9, 3.765752695376815*^9}, {3.765752762889865*^9, 
   3.7657528344833117`*^9}, {3.765752874069584*^9, 3.765752879176693*^9}, 
   3.7657530711110477`*^9, {3.765753105906846*^9, 3.765753329259696*^9}, {
   3.765753398655176*^9, 3.7657534041178226`*^9}, {3.765753457815214*^9, 
   3.765753564826425*^9}, {3.7657537158107853`*^9, 3.7657537922240553`*^9}, {
   3.765753825535211*^9, 3.765753833848229*^9}, {3.7657538773687572`*^9, 
   3.765753962447269*^9}, {3.765754030007886*^9, 3.765754077452463*^9}, {
   3.7657541464152517`*^9, 3.765754167731398*^9}, {3.765754243152821*^9, 
   3.765754272314884*^9}, {3.765754307480088*^9, 3.765754352670333*^9}, {
   3.765754447890786*^9, 3.765754453770588*^9}, {3.765754515079402*^9, 
   3.7657545359487753`*^9}, {3.765754717010128*^9, 3.7657548910739727`*^9}, {
   3.7657549310030212`*^9, 3.765754995502969*^9}, {3.766640653087933*^9, 
   3.766640698303123*^9}, {3.76664120750992*^9, 3.766641252491494*^9}}],

Cell[CellGroupData[{

Cell["Source code", "Section",
 CellChangeTimes->{{3.765709118423482*^9, 3.765709131386435*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"main", " ", 
    RowBox[{"procedure", ".", " ", 
     RowBox[{"nonlinearFlag", ":", " ", 
      RowBox[{"Boolean", " ", "flag", " ", "of", " ", "nonlinearity"}]}]}]}], 
   ";", " ", 
   RowBox[{"g", ":", " ", 
    RowBox[{"higher", "-", 
     RowBox[{
     "order", " ", "term", " ", "involved", " ", "in", " ", "the", " ", 
      "linearization"}]}]}], ";", " ", 
   RowBox[{"typeOfg", ":", " ", 
    RowBox[{"type", " ", "of", " ", "g"}]}], ";", " ", 
   RowBox[{"A", ":", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"list", " ", "of"}], ")"}], " ", "system", " ", "matrices", " ",
      "of", " ", "linearized", " ", "DDEs"}]}], ";", " ", 
   RowBox[{"r", ":", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"list", " ", "of"}], ")"}], " ", "constant", " ", "delays"}]}], 
   ";", " ", 
   RowBox[{"init", ":", " ", 
    RowBox[{"initial", " ", "set", " ", "of", " ", "states"}]}], ";", " ", 
   RowBox[{"unsafe", ":", " ", 
    RowBox[{"boundary", " ", "of", " ", "the", " ", "unsafe", " ", "set"}]}], 
   ";", " ", 
   RowBox[{"\[Alpha]", ":", " ", 
    RowBox[{
     RowBox[{
     "a", " ", "constant", " ", "obtained", " ", "through", " ", "DDE"}], "-", 
     RowBox[{
     "BIFTOOL", " ", "that", " ", "bounds", " ", "the", " ", "spectrum", " ", 
      "from", " ", "right"}]}]}]}], "*)"}]], "Input",
 CellChangeTimes->{{3.765755010185223*^9, 3.765755033948923*^9}, {
  3.765755321737472*^9, 3.765755348396353*^9}, {3.765755392502553*^9, 
  3.765755433974226*^9}, {3.765755466678597*^9, 3.765755474586241*^9}, {
  3.7657555133518343`*^9, 3.765755543896944*^9}, {3.765755581500181*^9, 
  3.765755600195566*^9}, {3.765755650047138*^9, 3.765755740258601*^9}, {
  3.765755772681802*^9, 3.765755780051497*^9}, {3.7657558576911087`*^9, 
  3.7657559039740467`*^9}, {3.7657559482560663`*^9, 3.765756102407384*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"main", "[", 
     RowBox[{
     "nonlinearFlag_", ",", "g_", ",", "typeOfg_", ",", "A_", ",", "r_", ",", 
      "init_", ",", "unsafe_", ",", "\[Alpha]_", ",", "vars_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "h", ",", "inverseh", ",", "n", ",", "M", ",", "K1", ",", "K2", ",", 
        "K", ",", "hatK", ",", "tideK", ",", "epsilon", ",", "delta", ",", 
        "deltaEpsilon", ",", "Tstar", ",", "t", ",", "time", ",", "i"}], 
       "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{"checking", " ", "validity", " ", "of", " ", "nonlinearFlag"}],
        "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"BooleanQ", "[", "nonlinearFlag", "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
          "Print", "[", "\"\<Invalid flag of nonlinearity. Abort.\>\"", "]"}],
           ";", "\[IndentingNewLine]", 
          RowBox[{"Return", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], ";",
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
        "checking", " ", "validity", " ", "of", " ", "matrices", " ", "in", 
         " ", "A"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"n", "=", 
        RowBox[{"Length", "[", 
         RowBox[{"A", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "A", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"!", 
             RowBox[{"MatrixQ", "[", 
              RowBox[{
               RowBox[{"A", "[", 
                RowBox[{"[", "i", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"NumberQ", "[", "#", "]"}], "&&", 
                 RowBox[{"!", 
                  RowBox[{"MatchQ", "[", 
                   RowBox[{"#", ",", "_Complex"}], "]"}]}]}], "&"}]}], 
              "]"}]}], "||", "\[IndentingNewLine]", 
            RowBox[{"!", 
             RowBox[{"SquareMatrixQ", "[", 
              RowBox[{"A", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "||", 
            RowBox[{
             RowBox[{"Length", "[", 
              RowBox[{"A", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}], "\[NotEqual]", "n"}]}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{
             "\"\<Invalid matrix A[[\>\"", ",", "i", ",", 
              "\"\<]]. Abort.\>\""}], "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{"Return", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "checking", " ", "validity", " ", "and", " ", "positivity", " ", 
          "of", " ", "\[Alpha]"}], ",", " ", 
         RowBox[{
         "and", " ", "thereby", " ", "stability", " ", "of", " ", "the", " ", 
          "system"}]}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"!", 
           RowBox[{"NumberQ", "[", "\[Alpha]", "]"}]}], "||", 
          RowBox[{"MatchQ", "[", 
           RowBox[{"\[Alpha]", ",", "_Complex"}], "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Print", "[", "\"\<Invalid \[Alpha]. Abort.\>\"", "]"}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"Return", "[", "]"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"\[Alpha]", "\[GreaterEqual]", "0"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
             "Print", "[", 
              "\"\<Instable or periodic system due to nonnegative \[Alpha]. \
Abort.\>\"", "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"Return", "[", "]"}], ";"}]}], "\[IndentingNewLine]", 
           "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
        "checking", " ", "validity", " ", "of", " ", "init", " ", "and", " ", 
         "unsafe"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"RegionQ", "[", 
           RowBox[{"ImplicitRegion", "[", 
            RowBox[{"init", ",", "vars"}], "]"}], "]"}]}], 
         RowBox[{"(*", 
          RowBox[{"||", 
           RowBox[{"!", 
            RowBox[{"RegionQ", "[", "unsafe", "]"}]}]}], "*)"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Print", "[", "\"\<Invalid init. Abort.\>\"", "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Return", "[", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}],
        ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"SetDirectory", "[", 
        RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"time", "=", 
        RowBox[{"TimeUsed", "[", "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"h", "=", 
        RowBox[{
         RowBox[{"z", " ", 
          RowBox[{"IdentityMatrix", "[", "n", "]"}]}], "-", 
         RowBox[{"Plus", "@@", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"A", "[", 
              RowBox[{"[", "i", "]"}], "]"}], " ", 
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"-", " ", 
                RowBox[{"r", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], " ", "z"}], "]"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", 
              RowBox[{"Length", "[", "r", "]"}]}], "}"}]}], "]"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<Bounding the spectrum from right: \[Alpha]=\>\"", ",", 
         "\[Alpha]"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"inverseh", "=", 
        RowBox[{"Inverse", "[", "h", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"M", "=", 
        RowBox[{"splitter", "[", 
         RowBox[{
         "A", ",", "r", ",", "n", ",", "h", ",", "inverseh", ",", 
          "\[Alpha]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Splitter: M=\>\"", ",", "M"}], "]"}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"inverseh", "=", 
        RowBox[{"inverseh", "/.", 
         RowBox[{"{", 
          RowBox[{"z", "\[Rule]", 
           RowBox[{"\[Alpha]", "+", 
            RowBox[{"v", " ", "\[ImaginaryI]"}]}]}], "}"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"\"\<Characteristic matrix: h(z)=\>\"", ",", "h"}], "]"}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<Inverse characteristic matrix: \!\(\*SuperscriptBox[\(h\), \
\(-1\)]\)(\[Alpha]+v\[ImaginaryI])=\>\"", ",", "inverseh"}], "]"}], ";"}], 
        "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"K1", "=", 
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          RowBox[{"Norm", "[", 
           RowBox[{
            RowBox[{"inverseh", "-", 
             RowBox[{
              RowBox[{"IdentityMatrix", "[", "n", "]"}], "/", 
              RowBox[{"(", 
               RowBox[{"\[Alpha]", "+", 
                RowBox[{"v", " ", "\[ImaginaryI]"}]}], ")"}]}]}], ",", 
            "Infinity"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"v", ",", 
            RowBox[{"-", "M"}], ",", "M"}], "}"}], ",", 
          RowBox[{"MaxRecursion", "\[Rule]", "100"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"K2", "=", 
        RowBox[{"8", 
         RowBox[{"n", "/", "M"}], 
         RowBox[{"(", 
          RowBox[{"Plus", "@@", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Norm", "[", 
               RowBox[{
                RowBox[{"A", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", "Infinity"}], "]"}], 
              " ", 
              RowBox[{"Exp", "[", 
               RowBox[{
                RowBox[{"-", " ", 
                 RowBox[{"r", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "\[Alpha]"}], " ", 
               "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "[", "r", "]"}]}], "}"}]}], "]"}]}], 
          ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"K", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"K1", "+", "K2"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", "\[Pi]"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", "nonlinearFlag"}], ",", "\[IndentingNewLine]", 
         RowBox[{"delta", "=", 
          RowBox[{"MaxValue", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Max", "[", 
               RowBox[{"Thread", "[", 
                RowBox[{"Abs", "[", "vars", "]"}], "]"}], "]"}], ",", 
              "init"}], "}"}], ",", "vars"}], "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"epsilon", "=", 
           RowBox[{
            RowBox[{"-", "\[Alpha]"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "K", " ", 
              RowBox[{"E", "^", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"r", "[", 
                   RowBox[{"[", 
                    RowBox[{"Length", "[", "r", "]"}], "]"}], "]"}]}], " ", 
                 "\[Alpha]"}], ")"}]}]}], ")"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"deltaEpsilon", "=", 
           RowBox[{"basin", "[", 
            RowBox[{"g", ",", "typeOfg", ",", "epsilon"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"delta", "=", 
           RowBox[{"Min", "[", 
            RowBox[{"deltaEpsilon", ",", 
             RowBox[{"deltaEpsilon", "/", 
              RowBox[{"(", 
               RowBox[{"K", " ", 
                RowBox[{"E", "^", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "r"}], " ", "\[Alpha]"}], ")"}]}], 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   RowBox[{"Plus", "@@", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"Norm", "[", 
                    RowBox[{
                    RowBox[{"A", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], ",", "Infinity"}], "]"}], 
                    " ", ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", "2", ",", 
                    RowBox[{"Length", "[", "r", "]"}]}], "}"}]}], "]"}]}], 
                   RowBox[{"NIntegrate", "[", 
                    RowBox[{
                    RowBox[{"E", "^", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "\[Alpha]"}], " ", "\[Tau]"}], ")"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Tau]", ",", "0", ",", 
                    RowBox[{"r", "[", 
                    RowBox[{"[", 
                    RowBox[{"Length", "[", "r", "]"}], "]"}], "]"}]}], "}"}], 
                    ",", 
                    RowBox[{"MaxRecursion", "\[Rule]", "40"}]}], "]"}]}]}], 
                 ")"}]}], ")"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"Print", "[", 
           RowBox[{"\"\<Delta: \[Delta]=\>\"", ",", "delta"}], "]"}], ";"}]}],
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"hatK", "=", 
        RowBox[{"K", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
            RowBox[{"Plus", "@@", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"Norm", "[", 
                RowBox[{
                 RowBox[{"A", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", "Infinity"}], "]"}], 
               " ", ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "2", ",", 
                 RowBox[{"Length", "[", "r", "]"}]}], "}"}]}], "]"}]}], 
            RowBox[{"NIntegrate", "[", 
             RowBox[{
              RowBox[{"E", "^", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "\[Alpha]"}], " ", "\[Tau]"}], ")"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Tau]", ",", "0", ",", 
                RowBox[{"r", "[", 
                 RowBox[{"[", 
                  RowBox[{"Length", "[", "r", "]"}], "]"}], "]"}]}], "}"}], 
              ",", 
              RowBox[{"MaxRecursion", "\[Rule]", "40"}]}], "]"}]}]}], ")"}], 
         "delta"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{"nonlinearFlag", ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"tideK", "=", 
            RowBox[{
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"r", "[", 
                 RowBox[{"[", 
                  RowBox[{"Length", "[", "r", "]"}], "]"}], "]"}]}], " ", 
               "\[Alpha]"}], " ", "]"}], " ", "hatK"}]}], ";"}]}], 
         "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<Constants: K1=\>\"", ",", "K1", ",", "\"\< K2=\>\"", ",", "K2", 
          ",", "\"\< K=\>\"", ",", "K", ",", 
          "\"\< \!\(\*OverscriptBox[\(K\), \(^\)]\)=\>\"", ",", "hatK"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", "nonlinearFlag"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Tstar", "=", 
           RowBox[{"Max", "[", 
            RowBox[{"0", ",", 
             RowBox[{"t", "/.", 
              RowBox[{"FindInstance", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"hatK", " ", 
                  RowBox[{"E", "^", 
                   RowBox[{"(", 
                    RowBox[{"\[Alpha]", " ", "t"}], ")"}]}]}], "\[Equal]", 
                 "unsafe"}], ",", "t", ",", "Reals"}], "]"}]}]}], "]"}]}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"\"\<tideK= \>\"", ",", "tideK"}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"Tstar", "=", 
            RowBox[{"Max", "[", 
             RowBox[{"0", ",", 
              RowBox[{"t", "/.", 
               RowBox[{"FindInstance", "[", " ", 
                RowBox[{
                 RowBox[{
                  RowBox[{"tideK", " ", 
                   RowBox[{"E", "^", 
                    RowBox[{"(", 
                    RowBox[{"t", " ", 
                    RowBox[{"\[Alpha]", "/", "2"}]}], " ", ")"}]}]}], " ", 
                  "\[Equal]", "unsafe"}], ",", "t", ",", "Reals"}], "]"}]}]}],
              "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<Bound: \!\(\*SuperscriptBox[\(T\), \(*\)]\)=\>\"", ",", 
          "Tstar"}], "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"time", "=", 
        RowBox[{
         RowBox[{"TimeUsed", "[", "]"}], "-", "time"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Elapsed time: \>\"", ",", "time"}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", "\n", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"constructing", " ", "a", " ", "threshold", " ", "M"}], ">", 
       RowBox[{
       "0", " ", "such", " ", "that", " ", "the", " ", "integral", " ", 
        "over"}]}], " ", "|", "v"}], "|>"}], "M", " ", "can", " ", "be", " ", 
    "bounded"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"splitter", "[", 
     RowBox[{
     "A_", ",", "r_", ",", "dim_", ",", "H_", ",", "invH_", ",", 
      "\[Alpha]_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "detH", ",", "adjH", ",", "coef", ",", "coef1", ",", "coef2", ",", 
        "coef3", ",", "detHcoef", ",", "detHcoef1", ",", "detHcoef2", ",", 
        "M"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"detH", "=", 
        RowBox[{"Det", "[", "H", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"adjH", "=", 
        RowBox[{"Simplify", "[", 
         RowBox[{"detH", " ", "invH"}], "]"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"coef", "=", " ", 
        RowBox[{"CoefficientList", "[", 
         RowBox[{"adjH", ",", "z"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"coef1", "=", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Head", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"coef", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "[", 
                  RowBox[{"[", "j", "]"}], "]"}], "[", 
                 RowBox[{"[", "k", "]"}], "]"}], "]"}], "===", " ", "Times"}],
               "||", " ", 
              RowBox[{
               RowBox[{"Head", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"coef", "[", 
                   RowBox[{"[", "i", "]"}], "]"}], "[", 
                  RowBox[{"[", "j", "]"}], "]"}], "[", 
                 RowBox[{"[", "k", "]"}], "]"}], "]"}], "===", " ", 
               "Power"}]}], ",", 
             RowBox[{"Abs", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"coef", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "[", 
                RowBox[{"[", "j", "]"}], "]"}], "[", 
               RowBox[{"[", "k", "]"}], "]"}], "]"}], ",", " ", 
             RowBox[{"Plus", "@@", 
              RowBox[{"Thread", "[", 
               RowBox[{"Abs", "[", 
                RowBox[{"List", "@@", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"coef", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "[", 
                   RowBox[{"[", "j", "]"}], "]"}], "[", 
                  RowBox[{"[", "k", "]"}], "]"}]}], "]"}], "]"}]}]}], "]"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "coef", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", 
             RowBox[{"Length", "[", "coef", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", 
             RowBox[{"Length", "[", 
              RowBox[{
               RowBox[{"coef", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "[", 
               RowBox[{"[", "j", "]"}], "]"}], "]"}]}], "}"}]}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{"z", "\[Rule]", " ", "\[Alpha]"}], "}"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"coef2", "=", 
        RowBox[{"Delete", "[", 
         RowBox[{"coef1", ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"i", ",", "i", ",", 
              RowBox[{"-", "1"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", "dim"}], "}"}]}], "]"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"coef3", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Plus", "@@", 
           RowBox[{
            RowBox[{"coef2", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "[", 
            RowBox[{"[", "j", "]"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "coef2", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", 
            RowBox[{"Length", "[", "coef2", "]"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"detHcoef", " ", "=", " ", 
        RowBox[{"CoefficientList", "[", " ", 
         RowBox[{"detH", ",", "z"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"detHcoef1", "=", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Head", "[", 
                RowBox[{"detHcoef", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "]"}], "===", "Times"}], "||",
               " ", 
              RowBox[{
               RowBox[{"Head", "[", 
                RowBox[{"detHcoef", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "]"}], "===", " ", 
               "Power"}]}], ",", 
             RowBox[{"Abs", "[", 
              RowBox[{"detHcoef", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
             RowBox[{"Plus", "@@", 
              RowBox[{"Thread", "[", 
               RowBox[{"Abs", "[", 
                RowBox[{"List", "@@", 
                 RowBox[{"detHcoef", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "]"}]}]}], "]"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "detHcoef", "]"}]}], "}"}]}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{"z", "\[Rule]", " ", "\[Alpha]"}], "}"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"detHcoef2", "=", 
        RowBox[{"Plus", "@@", 
         RowBox[{"Delete", "[", 
          RowBox[{"detHcoef1", ",", 
           RowBox[{"-", "1"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"M", "=", 
        RowBox[{"Max", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", "coef3", "]"}], ",", 
          RowBox[{"2", " ", "detHcoef2"}], ",", "1"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"Return", "[", "M", "]"}], ";"}]}], "\[IndentingNewLine]", 
     "]"}]}], ";"}], "\[IndentingNewLine]", "\n", 
  RowBox[{"(*", 
   RowBox[{
   "subrutine", " ", "for", " ", "assembling", " ", "the", " ", "basin", " ", 
    "of", " ", "attraction"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"basin", "[", 
    RowBox[{"g_", ",", "typeOfg_", ",", "epsilon_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"g1", ",", "dd", ",", "dd1"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{
       "Note", " ", "that", " ", "there", " ", "is", " ", "no", " ", 
        "unified", " ", "approach", " ", "to", " ", "computing", " ", 
        "deltaEpsilon", " ", "for", " ", "general", " ", "type", " ", "of", 
        " ", "g"}], ",", " ", 
       RowBox[{
       "and", " ", "we", " ", "provide", " ", "in", " ", "the", " ", 
        "following", " ", "two", " ", "typical", " ", "cases", " ", 
        "concerning", " ", "polynomial", " ", "g", " ", "and", " ", 
        "monotonic", " ", "rational", " ", "g"}]}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"Switch", "[", 
      RowBox[{"typeOfg", ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
        "if", " ", "g", " ", "is", " ", "a", " ", "polynomail", " ", 
         "function"}], "*)"}], "\[IndentingNewLine]", "\"\<polynomial\>\"", 
       ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"g1", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Plus", "@@", 
            RowBox[{"Thread", "[", 
             RowBox[{"Abs", "[", 
              RowBox[{"MonomialList", "[", "g", "]"}], "]"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "g", "]"}]}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"g1", "=", 
         RowBox[{"g1", "/.", 
          RowBox[{"Thread", "[", 
           RowBox[{
            RowBox[{"Variables", "[", "g", "]"}], "\[Rule]", "x"}], "]"}]}]}],
         ";", "\[IndentingNewLine]", 
        RowBox[{"g1", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Simplify", "[", 
            RowBox[{
             RowBox[{"g1", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "/", 
             RowBox[{"Abs", "[", "x", "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "g1", "]"}]}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"dd", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"g1", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "===", "0"}], ",", "Infinity", 
             ",", 
             RowBox[{"x", "/.", 
              RowBox[{
               RowBox[{"Quiet", "[", 
                RowBox[{"NSolve", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"g1", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "epsilon"}], "&&", 
                   RowBox[{"x", "\[GreaterEqual]", "0"}]}], ",", "Reals"}], 
                 "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "g1", "]"}]}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Return", "[", 
         RowBox[{"Min", "[", "dd", "]"}], "]"}]}], ",", "\[IndentingNewLine]",
        "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"if", " ", 
         RowBox[{"g1", "/", "x"}], " ", "is", " ", "a", " ", "univariate", 
         " ", "monotonic", " ", "rational", " ", "function"}], "*)"}], 
       "\[IndentingNewLine]", "\"\<monotonic\>\"", ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"g1", "=", 
         RowBox[{"(", 
          RowBox[{"g", "/.", 
           RowBox[{"Thread", "[", 
            RowBox[{
             RowBox[{"Variables", "[", "g", "]"}], "\[Rule]", "x"}], "]"}]}], 
          ")"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"g1", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{"Simplify", "[", 
             RowBox[{
              RowBox[{"g1", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "/", "x"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "g1", "]"}]}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"dd", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"g1", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "===", "0"}], ",", "Infinity", 
             ",", 
             RowBox[{"x", "/.", 
              RowBox[{
               RowBox[{"Quiet", "[", 
                RowBox[{"NSolve", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"g1", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "epsilon"}], "&&", 
                   RowBox[{"x", "\[GreaterEqual]", "0"}]}], ",", "Reals"}], 
                 "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "g1", "]"}]}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"dd1", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"g1", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "===", "0"}], ",", "Infinity", 
             ",", 
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{"x", "/.", 
                RowBox[{
                 RowBox[{"Quiet", "[", 
                  RowBox[{"NSolve", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"g1", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "epsilon"}], "&&", 
                    RowBox[{"x", "\[LessEqual]", "0"}]}], ",", "Reals"}], 
                   "]"}], "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"Length", "[", "g1", "]"}]}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"dd", "=", 
         RowBox[{"Join", "[", 
          RowBox[{"dd", ",", "dd1"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Return", "[", 
         RowBox[{"Min", "[", "dd", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
       "more", " ", "cases", " ", "can", " ", "be", " ", "encoded", " ", 
        "here"}], "*)"}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7584366068184333`*^9, 3.758436637796452*^9}, {
   3.765181629994814*^9, 3.7651816665643573`*^9}, {3.765752993178405*^9, 
   3.765752998837816*^9}, 3.765754597038884*^9, {3.765756800385944*^9, 
   3.765756814937127*^9}, {3.7657568537053347`*^9, 3.7657568741678143`*^9}, 
   3.765756905175565*^9, {3.765756943175329*^9, 3.765757021526431*^9}, {
   3.7657570528512287`*^9, 3.765757111926779*^9}, {3.7657571530989027`*^9, 
   3.765757157799512*^9}, {3.765757241309127*^9, 3.765757241725275*^9}, {
   3.76575727617452*^9, 3.765757317280998*^9}, {3.7657573860520983`*^9, 
   3.765757428413457*^9}, {3.765757458740238*^9, 3.7657574609845743`*^9}, {
   3.7657575610822678`*^9, 3.765757854716751*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Experiments in the CAV'19 paper", "Section",
 CellChangeTimes->{{3.7584363578356447`*^9, 3.7584363818812113`*^9}, {
   3.7656319485405493`*^9, 3.765631953095035*^9}, {3.765718977420862*^9, 
   3.765719016647216*^9}, {3.765757904448715*^9, 3.765757955709709*^9}, 
   3.766640891473435*^9}],

Cell[CellGroupData[{

Cell["Example 2: PD-controller", "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.7657580324007673`*^9, 3.765758090535137*^9}}],

Cell[BoxData[
 RowBox[{"main", "[", 
  RowBox[{"False", ",", "0", ",", "\"\<\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", 
         RowBox[{"-", "3"}]}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0.35"}], "}"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "0.1"}], "\[LessEqual]", "y", "\[LessEqual]", "0.1"}], "&&", 
    RowBox[{"0", "\[LessEqual]", "v", "\[LessEqual]", "0.1"}]}], ",", "0.2", 
   ",", 
   RowBox[{"-", "0.5"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "v"}], "}"}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.7651826905268354`*^9, 3.765182690886304*^9}, {
  3.765755226664263*^9, 3.765755250703336*^9}, {3.765757175320524*^9, 
  3.765757197804213*^9}, {3.7657579930293713`*^9, 3.765758032400897*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Bounding the spectrum from right: \[Alpha]=\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.5`"}]}],
  SequenceForm["Bounding the spectrum from right: \[Alpha]=", -0.5],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.758436681609578*^9, 3.7651777649425077`*^9, 
  3.7651827108345623`*^9, 3.7652713227420287`*^9, 3.7654633527182713`*^9, 
  3.765755252824424*^9, 3.7657571199031477`*^9, 3.765757167222055*^9, 
  3.765757210828865*^9, 3.765758032400997*^9, 3.7657590217418823`*^9, 
  3.765759079006122*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Splitter: M=\"\>", "\[InvisibleSpace]", "11.912462166123582`"}],
  SequenceForm["Splitter: M=", 11.912462166123582`],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.758436681609578*^9, 3.7651777649425077`*^9, 
  3.7651827108345623`*^9, 3.7652713227420287`*^9, 3.7654633527182713`*^9, 
  3.765755252824424*^9, 3.7657571199031477`*^9, 3.765757167222055*^9, 
  3.765757210828865*^9, 3.765758032400997*^9, 3.7657590217418823`*^9, 
  3.765759079039556*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Constants: K1=\"\>", "\[InvisibleSpace]", "38.35644030279067`",
    "\[InvisibleSpace]", "\<\" K2=\"\>", "\[InvisibleSpace]", 
   "9.34313123323073`", "\[InvisibleSpace]", "\<\" K=\"\>", 
   "\[InvisibleSpace]", "7.591622593323278`", 
   "\[InvisibleSpace]", "\<\" \\!\\(\\*OverscriptBox[\\(K\\), \
\\(^\\)]\\)=\"\>", "\[InvisibleSpace]", "2.2110313582543046`"}],
  SequenceForm[
  "Constants: K1=", 38.35644030279067, " K2=", 9.34313123323073, " K=", 
   7.591622593323278, " \!\(\*OverscriptBox[\(K\), \(^\)]\)=", 
   2.2110313582543046`],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.758436681609578*^9, 3.7651777649425077`*^9, 
  3.7651827108345623`*^9, 3.7652713227420287`*^9, 3.7654633527182713`*^9, 
  3.765755252824424*^9, 3.7657571199031477`*^9, 3.765757167222055*^9, 
  3.765757210828865*^9, 3.765758032400997*^9, 3.7657590217418823`*^9, 
  3.76575908412376*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Bound: \\!\\(\\*SuperscriptBox[\\(T\\), \\(*\\)]\\)=\"\>", 
   "\[InvisibleSpace]", "4.805793994093204`"}],
  SequenceForm[
  "Bound: \!\(\*SuperscriptBox[\(T\), \(*\)]\)=", 4.805793994093204],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.758436681609578*^9, 3.7651777649425077`*^9, 
  3.7651827108345623`*^9, 3.7652713227420287`*^9, 3.7654633527182713`*^9, 
  3.765755252824424*^9, 3.7657571199031477`*^9, 3.765757167222055*^9, 
  3.765757210828865*^9, 3.765758032400997*^9, 3.7657590217418823`*^9, 
  3.765759084154929*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Elapsed time: \"\>", "\[InvisibleSpace]", "2.366022`"}],
  SequenceForm["Elapsed time: ", 2.366022],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.758436681609578*^9, 3.7651777649425077`*^9, 
  3.7651827108345623`*^9, 3.7652713227420287`*^9, 3.7654633527182713`*^9, 
  3.765755252824424*^9, 3.7657571199031477`*^9, 3.765757167222055*^9, 
  3.765757210828865*^9, 3.765758032400997*^9, 3.7657590217418823`*^9, 
  3.7657590841921873`*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.7584363886072893`*^9, 3.7584364097328176`*^9}, {
   3.758436695437184*^9, 3.7584366963458424`*^9}, {3.765631962123905*^9, 
   3.765631966809307*^9}, 3.76571903841718*^9, {3.765758393137753*^9, 
   3.765758394523608*^9}}],

Cell[CellGroupData[{

Cell["Example 3: Population dynamics", "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.7657580324007673`*^9, 3.765758093319584*^9}}],

Cell[BoxData[
 RowBox[{"main", "[", 
  RowBox[{"True", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "x"}], " ", "y"}], "}"}], ",", "\"\<polynomial\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", "0", "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"-", "1"}], "}"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ",", 
   RowBox[{
    RowBox[{"-", "0.2"}], "\[LessEqual]", "u", "\[LessEqual]", "0.2"}], ",", 
   "0.6", ",", 
   RowBox[{"-", "0.3"}], ",", 
   RowBox[{"{", "u", "}"}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.765182673827628*^9, 3.765182682481884*^9}, 
   3.765758080294915*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Bounding the spectrum from right: \[Alpha]=\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.3`"}]}],
  SequenceForm["Bounding the spectrum from right: \[Alpha]=", -0.3],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7584367349561133`*^9, 3.7651777780488024`*^9, 
  3.7651827621975436`*^9, 3.765271332610211*^9, 3.7654633637348957`*^9, 
  3.7657580802950363`*^9, 3.765759027491436*^9, 3.7657590844076443`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Splitter: M=\"\>", "\[InvisibleSpace]", "2.6997176151520064`"}],
  SequenceForm["Splitter: M=", 2.6997176151520064`],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7584367349561133`*^9, 3.7651777780488024`*^9, 
  3.7651827621975436`*^9, 3.765271332610211*^9, 3.7654633637348957`*^9, 
  3.7657580802950363`*^9, 3.765759027491436*^9, 3.7657590844097*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Delta: \[Delta]=\"\>", "\[InvisibleSpace]", 
   "0.0035167766702109207`"}],
  SequenceForm["Delta: \[Delta]=", 0.0035167766702109207`],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7584367349561133`*^9, 3.7651777780488024`*^9, 
  3.7651827621975436`*^9, 3.765271332610211*^9, 3.7654633637348957`*^9, 
  3.7657580802950363`*^9, 3.765759027491436*^9, 3.7657590845806837`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Constants: K1=\"\>", "\[InvisibleSpace]", 
   "16.654556834171522`", "\[InvisibleSpace]", "\<\" K2=\"\>", 
   "\[InvisibleSpace]", "4.`", "\[InvisibleSpace]", "\<\" K=\"\>", 
   "\[InvisibleSpace]", "3.2872748175308866`", 
   "\[InvisibleSpace]", "\<\" \\!\\(\\*OverscriptBox[\\(K\\), \
\\(^\\)]\\)=\"\>", "\[InvisibleSpace]", "0.025042550435724405`"}],
  SequenceForm[
  "Constants: K1=", 16.654556834171522`, " K2=", 4., " K=", 
   3.2872748175308866`, " \!\(\*OverscriptBox[\(K\), \(^\)]\)=", 
   0.025042550435724405`],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7584367349561133`*^9, 3.7651777780488024`*^9, 
  3.7651827621975436`*^9, 3.765271332610211*^9, 3.7654633637348957`*^9, 
  3.7657580802950363`*^9, 3.765759027491436*^9, 3.765759084592657*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"tideK= \"\>", "\[InvisibleSpace]", "0.03380390726982886`"}],
  SequenceForm["tideK= ", 0.03380390726982886],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7584367349561133`*^9, 3.7651777780488024`*^9, 
  3.7651827621975436`*^9, 3.765271332610211*^9, 3.7654633637348957`*^9, 
  3.7657580802950363`*^9, 3.765759027491436*^9, 3.7657590845932913`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Bound: \\!\\(\\*SuperscriptBox[\\(T\\), \\(*\\)]\\)=\"\>", 
   "\[InvisibleSpace]", "0"}],
  SequenceForm["Bound: \!\(\*SuperscriptBox[\(T\), \(*\)]\)=", 0],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7584367349561133`*^9, 3.7651777780488024`*^9, 
  3.7651827621975436`*^9, 3.765271332610211*^9, 3.7654633637348957`*^9, 
  3.7657580802950363`*^9, 3.765759027491436*^9, 3.765759084654317*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Elapsed time: \"\>", "\[InvisibleSpace]", 
   "0.047814000000000245`"}],
  SequenceForm["Elapsed time: ", 0.047814000000000245`],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7584367349561133`*^9, 3.7651777780488024`*^9, 
  3.7651827621975436`*^9, 3.765271332610211*^9, 3.7654633637348957`*^9, 
  3.7657580802950363`*^9, 3.765759027491436*^9, 3.76575908465487*^9}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{3.76517779407627*^9, 3.765719121970436*^9, 
  3.7657584069926043`*^9}],

Cell[CellGroupData[{

Cell["Example 4: Disease pathology", "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.7657580324007673`*^9, 3.765758093319584*^9}, {
  3.765758422314352*^9, 3.7657584247831497`*^9}}],

Cell[BoxData[
 RowBox[{"main", "[", 
  RowBox[{"True", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.5"}], 
     RowBox[{
      RowBox[{"y", "^", "2"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", "y"}], ")"}]}]}], "}"}], ",", "\"\<monotonic\>\"", 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"-", "0.6"}], "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", "0.5", "}"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0.5"}], "}"}], ",", 
   RowBox[{
    RowBox[{"-", "0.1"}], "\[LessEqual]", "x", "\[LessEqual]", "0.1"}], ",", 
   "0.3", ",", 
   RowBox[{"-", "0.07"}], ",", 
   RowBox[{"{", "x", "}"}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.7651778079168253`*^9, 3.765177937761375*^9}, {
   3.765177995669797*^9, 3.7651780305835233`*^9}, {3.7651817297682867`*^9, 
   3.765181745296093*^9}, {3.765182100774481*^9, 3.765182104836032*^9}, 
   3.7657584377207403`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Bounding the spectrum from right: \[Alpha]=\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.07`"}]}],
  SequenceForm["Bounding the spectrum from right: \[Alpha]=", -0.07],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7651817464518976`*^9, 3.7651818997440863`*^9, 
  3.765182126815277*^9, 3.765182370508107*^9, 3.7651824088428926`*^9, 
  3.765182445303102*^9, 3.765182491167349*^9, 3.7651825691334286`*^9, 
  3.7651828248703256`*^9, 3.765271353068695*^9, 3.7652716939842825`*^9, 
  3.7652717381483097`*^9, 3.7654633822017937`*^9, 3.765758437720791*^9, 
  3.765759027777609*^9, 3.765759084724648*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Splitter: M=\"\>", "\[InvisibleSpace]", "2.2356197087996232`"}],
  SequenceForm["Splitter: M=", 2.2356197087996232`],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7651817464518976`*^9, 3.7651818997440863`*^9, 
  3.765182126815277*^9, 3.765182370508107*^9, 3.7651824088428926`*^9, 
  3.765182445303102*^9, 3.765182491167349*^9, 3.7651825691334286`*^9, 
  3.7651828248703256`*^9, 3.765271353068695*^9, 3.7652716939842825`*^9, 
  3.7652717381483097`*^9, 3.7654633822017937`*^9, 3.765758437720791*^9, 
  3.765759027777609*^9, 3.765759084725133*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Delta: \[Delta]=\"\>", "\[InvisibleSpace]", 
   "0.016342601315065125`"}],
  SequenceForm["Delta: \[Delta]=", 0.016342601315065125`],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7651817464518976`*^9, 3.7651818997440863`*^9, 
  3.765182126815277*^9, 3.765182370508107*^9, 3.7651824088428926`*^9, 
  3.765182445303102*^9, 3.765182491167349*^9, 3.7651825691334286`*^9, 
  3.7651828248703256`*^9, 3.765271353068695*^9, 3.7652716939842825`*^9, 
  3.7652717381483097`*^9, 3.7654633822017937`*^9, 3.765758437720791*^9, 
  3.765759027777609*^9, 3.7657590847969217`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Constants: K1=\"\>", "\[InvisibleSpace]", "7.000689655564135`",
    "\[InvisibleSpace]", "\<\" K2=\"\>", "\[InvisibleSpace]", "4.`", 
   "\[InvisibleSpace]", "\<\" K=\"\>", "\[InvisibleSpace]", 
   "1.7508141361029115`", 
   "\[InvisibleSpace]", "\<\" \\!\\(\\*OverscriptBox[\\(K\\), \
\\(^\\)]\\)=\"\>", "\[InvisibleSpace]", "0.03589272632185238`"}],
  SequenceForm[
  "Constants: K1=", 7.000689655564135, " K2=", 4., " K=", 1.7508141361029115`,
    " \!\(\*OverscriptBox[\(K\), \(^\)]\)=", 0.03589272632185238],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7651817464518976`*^9, 3.7651818997440863`*^9, 
  3.765182126815277*^9, 3.765182370508107*^9, 3.7651824088428926`*^9, 
  3.765182445303102*^9, 3.765182491167349*^9, 3.7651825691334286`*^9, 
  3.7651828248703256`*^9, 3.765271353068695*^9, 3.7652716939842825`*^9, 
  3.7652717381483097`*^9, 3.7654633822017937`*^9, 3.765758437720791*^9, 
  3.765759027777609*^9, 3.7657590848393383`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"tideK= \"\>", "\[InvisibleSpace]", "0.037171214781461334`"}],
  SequenceForm["tideK= ", 0.037171214781461334`],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7651817464518976`*^9, 3.7651818997440863`*^9, 
  3.765182126815277*^9, 3.765182370508107*^9, 3.7651824088428926`*^9, 
  3.765182445303102*^9, 3.765182491167349*^9, 3.7651825691334286`*^9, 
  3.7651828248703256`*^9, 3.765271353068695*^9, 3.7652716939842825`*^9, 
  3.7652717381483097`*^9, 3.7654633822017937`*^9, 3.765758437720791*^9, 
  3.765759027777609*^9, 3.765759084854026*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Bound: \\!\\(\\*SuperscriptBox[\\(T\\), \\(*\\)]\\)=\"\>", 
   "\[InvisibleSpace]", "0"}],
  SequenceForm["Bound: \!\(\*SuperscriptBox[\(T\), \(*\)]\)=", 0],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7651817464518976`*^9, 3.7651818997440863`*^9, 
  3.765182126815277*^9, 3.765182370508107*^9, 3.7651824088428926`*^9, 
  3.765182445303102*^9, 3.765182491167349*^9, 3.7651825691334286`*^9, 
  3.7651828248703256`*^9, 3.765271353068695*^9, 3.7652716939842825`*^9, 
  3.7652717381483097`*^9, 3.7654633822017937`*^9, 3.765758437720791*^9, 
  3.765759027777609*^9, 3.765759084885005*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Elapsed time: \"\>", "\[InvisibleSpace]", 
   "0.03968999999999978`"}],
  SequenceForm["Elapsed time: ", 0.03968999999999978],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7651817464518976`*^9, 3.7651818997440863`*^9, 
  3.765182126815277*^9, 3.765182370508107*^9, 3.7651824088428926`*^9, 
  3.765182445303102*^9, 3.765182491167349*^9, 3.7651825691334286`*^9, 
  3.7651828248703256`*^9, 3.765271353068695*^9, 3.7652716939842825`*^9, 
  3.7652717381483097`*^9, 3.7654633822017937`*^9, 3.765758437720791*^9, 
  3.765759027777609*^9, 3.765759084885598*^9}]
}, Open  ]],

Cell[BoxData[" "], "Input",
 CellChangeTimes->{3.765758456828356*^9}],

Cell[CellGroupData[{

Cell["Example 5: Gene regulation", "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.7657580324007673`*^9, 3.765758093319584*^9}, {
  3.765758422314352*^9, 3.7657584247831497`*^9}, {3.765758464688382*^9, 
  3.765758467143076*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"systemMatrices", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", 
          RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
          RowBox[{"-", "1"}]}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1", ",", "0"}], "}"}]}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", 
          RowBox[{"-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
       "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{"main", "[", 
  RowBox[{"False", ",", "0", ",", "\"\<\>\"", ",", "systemMatrices", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0.1", ",", "0.2", ",", "0.4", ",", "0.8", ",", "1.6"}],
     "}"}], ",", 
   RowBox[{
    RowBox[{"-", "0.8"}], "\[LessEqual]", "y", "\[LessEqual]", "1.2"}], ",", 
   "1.5", ",", 
   RowBox[{"-", "0.04"}], ",", 
   RowBox[{"{", "y", "}"}]}], "]"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.7584364473835545`*^9, 3.758436508019941*^9}, 
   3.765182807171574*^9, {3.765631978027528*^9, 3.765631984404813*^9}, 
   3.7657191140034924`*^9, {3.7657581381481047`*^9, 3.7657581637898293`*^9}, {
   3.7657581962768173`*^9, 3.765758217220083*^9}, {3.7657584484030523`*^9, 
   3.76575851115451*^9}, {3.7657590080330343`*^9, 3.765759010963022*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Bounding the spectrum from right: \[Alpha]=\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.04`"}]}],
  SequenceForm["Bounding the spectrum from right: \[Alpha]=", -0.04],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7584367506235447`*^9, 3.765177786781167*^9, 
  3.7651828173096232`*^9, 3.765463374256997*^9, 3.765758492663007*^9, 
  3.765759027991218*^9, 3.76575908494715*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Splitter: M=\"\>", "\[InvisibleSpace]", "64.26403174199835`"}],
  SequenceForm["Splitter: M=", 64.26403174199835],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7584367506235447`*^9, 3.765177786781167*^9, 
  3.7651828173096232`*^9, 3.765463374256997*^9, 3.765758492663007*^9, 
  3.765759027991218*^9, 3.765759085123246*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Constants: K1=\"\>", "\[InvisibleSpace]", 
   "23.971199045015155`", "\[InvisibleSpace]", "\<\" K2=\"\>", 
   "\[InvisibleSpace]", "3.8135040828135978`", 
   "\[InvisibleSpace]", "\<\" K=\"\>", "\[InvisibleSpace]", 
   "4.4220728451347915`", 
   "\[InvisibleSpace]", "\<\" \\!\\(\\*OverscriptBox[\\(K\\), \
\\(^\\)]\\)=\"\>", "\[InvisibleSpace]", "49.1462976891227`"}],
  SequenceForm[
  "Constants: K1=", 23.971199045015155`, " K2=", 3.8135040828135978`, " K=", 
   4.4220728451347915`, " \!\(\*OverscriptBox[\(K\), \(^\)]\)=", 
   49.1462976891227],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7584367506235447`*^9, 3.765177786781167*^9, 
  3.7651828173096232`*^9, 3.765463374256997*^9, 3.765758492663007*^9, 
  3.765759027991218*^9, 3.765759088969483*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Bound: \\!\\(\\*SuperscriptBox[\\(T\\), \\(*\\)]\\)=\"\>", 
   "\[InvisibleSpace]", "87.23341022187815`"}],
  SequenceForm[
  "Bound: \!\(\*SuperscriptBox[\(T\), \(*\)]\)=", 87.23341022187815],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7584367506235447`*^9, 3.765177786781167*^9, 
  3.7651828173096232`*^9, 3.765463374256997*^9, 3.765758492663007*^9, 
  3.765759027991218*^9, 3.765759089005536*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Elapsed time: \"\>", "\[InvisibleSpace]", "2.059973`"}],
  SequenceForm["Elapsed time: ", 2.059973],
  Editable->False]], "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.7584367506235447`*^9, 3.765177786781167*^9, 
  3.7651828173096232`*^9, 3.765463374256997*^9, 3.765758492663007*^9, 
  3.765759027991218*^9, 3.765759089011752*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{960, 1148},
WindowMargins->{{Automatic, -10}, {Automatic, -10}},
FrontEndVersion->"10.0 for Linux x86 (64-bit) (December 4, 2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 502, 9, 150, "Title"],
Cell[1085, 33, 3248, 66, 387, "Text"],
Cell[CellGroupData[{
Cell[4358, 103, 96, 1, 65, "Section"],
Cell[4457, 106, 1880, 43, 121, "Input"],
Cell[6340, 151, 30893, 760, 3101, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[37270, 916, 294, 4, 51, "Section"],
Cell[CellGroupData[{
Cell[37589, 924, 167, 2, 45, "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[37759, 928, 1155, 32, 55, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[38917, 962, 612, 12, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[39532, 976, 557, 10, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[40092, 988, 980, 18, 25, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[41075, 1008, 633, 12, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[41711, 1022, 542, 10, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[42268, 1035, 269, 4, 32, "Input"],
Cell[CellGroupData[{
Cell[42562, 1043, 173, 2, 45, "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[42738, 1047, 743, 22, 55, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[43484, 1071, 518, 10, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[44005, 1083, 459, 8, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[44467, 1093, 481, 9, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[44951, 1104, 867, 16, 25, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[45821, 1122, 454, 8, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[46278, 1132, 501, 9, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[46782, 1143, 472, 9, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[47269, 1155, 116, 2, 32, "Input"],
Cell[CellGroupData[{
Cell[47410, 1161, 222, 3, 45, "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[47635, 1166, 1012, 29, 55, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[48650, 1197, 709, 13, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[49362, 1212, 652, 11, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[50017, 1225, 670, 12, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[50690, 1239, 1050, 18, 25, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[51743, 1259, 646, 11, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[52392, 1272, 692, 12, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[53087, 1286, 661, 12, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]],
Cell[53763, 1301, 69, 1, 32, "Input"],
Cell[CellGroupData[{
Cell[53857, 1306, 269, 4, 45, "Subsection",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[54129, 1312, 4526, 105, 231, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[58658, 1419, 489, 10, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[59150, 1431, 430, 8, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[59583, 1441, 867, 17, 25, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[60453, 1460, 509, 10, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[60965, 1472, 416, 8, 23, "Print",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
